@@ -140,6 +140,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     private boolean mIsAudioTrack = false;
     private boolean mHasHdmiAudio = false;
     private boolean mSwitchingToVideo = false;
+    private boolean mVideoBackground = false;
 
     final private ArrayList<Callback> mCallbacks = new ArrayList<Callback>();
     private boolean mDetectHeadset = true;
@@ -620,10 +621,11 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                     changeAudioFocus(true);
                     if (!mWakeLock.isHeld())
                         mWakeLock.acquire();
-                    if (switchToVideo())
-                        hideNotification();
+                    if (!mVideoBackground && switchToVideo())
+                        hideNotification(false);
                     else
                         showNotification();
+                    mVideoBackground = false;
                     break;
                 case MediaPlayer.Event.Paused:
                     Log.i(TAG, "MediaPlayer.Event.Paused");
@@ -670,7 +672,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                 case MediaPlayer.Event.Vout:
                     break;
                 case MediaPlayer.Event.ESAdded:
-                    if (event.getEsChangedType() == Media.Track.Type.Video && !switchToVideo()) {
+                    if (event.getEsChangedType() == Media.Track.Type.Video && (mVideoBackground || !switchToVideo())) {
                         /* Update notification content intent: resume video or resume audio activity */
                         updateMetadata();
                     }
@@ -753,6 +755,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     public boolean switchToVideo() {
         if (mMediaList.getMedia(mCurrentIndex).hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO) || !canSwitchToVideo())
             return false;
+        mVideoBackground = false;
         if (isVideoPlaying()) {//Player is already running, just send it an intent
             setVideoTrackEnabled(true);
             LocalBroadcastManager.getInstance(this).sendBroadcast(
@@ -871,7 +874,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
 
 
             PendingIntent pendingIntent;
-            if (canSwitchToVideo() && !mMediaList.getMedia(mCurrentIndex).hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO) ) {
+            if (mVideoBackground || (canSwitchToVideo() && !mMediaList.getMedia(mCurrentIndex).hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO))) {
                 /* Resume VideoPlayerActivity from ACTION_REMOTE_SWITCH_VIDEO intent */
                 final Intent notificationIntent = new Intent(ACTION_REMOTE_SWITCH_VIDEO);
                 pendingIntent = PendingIntent.getBroadcast(this, 0, notificationIntent, PendingIntent.FLAG_UPDATE_CURRENT);
@@ -1135,6 +1138,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         bob.putString(MediaMetadataCompat.METADATA_KEY_TITLE, title)
             .putString(MediaMetadataCompat.METADATA_KEY_GENRE, MediaUtils.getMediaGenre(this, media))
                 .putLong(MediaMetadataCompat.METADATA_KEY_TRACK_NUMBER, media.getTrackNumber())
+                .putString(MediaMetadataCompat.METADATA_KEY_ARTIST, MediaUtils.getMediaArtist(this, media))
                 .putString(MediaMetadataCompat.METADATA_KEY_ALBUM_ARTIST, MediaUtils.getMediaReferenceArtist(this, media))
                 .putString(MediaMetadataCompat.METADATA_KEY_ALBUM, MediaUtils.getMediaAlbum(this, media))
                 .putLong(MediaMetadataCompat.METADATA_KEY_DURATION, media.getLength());
@@ -1210,6 +1214,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
             stop();
             return;
         }
+        mVideoBackground = !isVideoPlaying() && canSwitchToVideo();
         playIndex(mCurrentIndex, 0);
         saveCurrentMedia();
     }
@@ -1217,7 +1222,8 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     @MainThread
     public void previous() {
         int size = mMediaList.size();
-        if (hasPrevious() && mCurrentIndex > 0 && mMediaPlayer.getTime() < 2000l) {
+        if (hasPrevious() && mCurrentIndex > 0 &&
+                (!mMediaPlayer.isSeekable() || mMediaPlayer.getTime() < 2000l)) {
             mCurrentIndex = mPrevIndex;
             if (mPrevious.size() > 0)
                 mPrevious.pop();
@@ -1449,6 +1455,11 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         return mShuffling;
     }
 
+    @MainThread
+    public boolean canShuffle()  {
+        return getMediaListSize() > 2;
+    }
+
     @MainThread
     public int getRepeatType() {
         return mRepeating;
@@ -1459,6 +1470,11 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         return hasCurrentMedia();
     }
 
+    @MainThread
+    public boolean hasPlaylist()  {
+        return getMediaListSize() > 1;
+    }
+
     @MainThread
     public boolean isVideoPlaying() {
         return mMediaPlayer.getVLCVout().areViewsAttached();
@@ -1681,9 +1697,12 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         final MediaWrapper mw = mMediaList.getMedia(index);
         if (mw == null)
             return;
-        if (mw.getType() == MediaWrapper.TYPE_VIDEO && isVideoPlaying())
+        if (!mVideoBackground && mw.getType() == MediaWrapper.TYPE_VIDEO && isVideoPlaying())
             mw.addFlags(MediaWrapper.MEDIA_VIDEO);
 
+        if (mVideoBackground)
+            mw.addFlags(MediaWrapper.MEDIA_FORCE_AUDIO);
+
         /* Pausable and seekable are true by default */
         mParsed = false;
         mSwitchingToVideo = false;
@@ -1691,10 +1710,11 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         final Media media = new Media(VLCInstance.get(), mw.getUri());
         VLCOptions.setMediaOptions(media, this, flags | mw.getFlags());
         media.setEventListener(mMediaListener);
-        if (mMediaPlayer.getMedia() == null || !mw.getUri().equals(mMediaPlayer.getMedia().getUri()))
-            mMediaPlayer.setMedia(media);
+        mMediaPlayer.setMedia(media);
         media.release();
-        if (mw .getType() != MediaWrapper.TYPE_VIDEO || mw.hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO) || isVideoPlaying()) {
+
+        if (mw .getType() != MediaWrapper.TYPE_VIDEO || mw.hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO)
+                || isVideoPlaying()) {
             mMediaPlayer.setEqualizer(VLCOptions.getEqualizer(this));
             mMediaPlayer.setVideoTitleDisplay(MediaPlayer.Position.Disable, 0);
             changeAudioFocus(true);
@@ -1763,6 +1783,11 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         mPopupManager = null;
     }
 
+    @MainThread
+    public boolean isPlayingPopup() {
+        return mPopupManager != null;
+    }
+
     @MainThread
     public void showPopup() {
         if (mPopupManager == null)
