@@ -67,7 +67,6 @@ public class FileBrowserFragment extends BaseBrowserFragment {
     @Override
     public void onViewCreated(View view, Bundle savedInstanceState) {
         super.onViewCreated(view, savedInstanceState);
-        mEmptyView.setText(getString(R.string.directory_empty));
     }
 
     @Override
@@ -111,7 +110,7 @@ public class FileBrowserFragment extends BaseBrowserFragment {
                     directory = new MediaWrapper(AndroidUtil.PathToUri(mediaDirLocation));
                     directory.setType(MediaWrapper.TYPE_DIR);
                     if (TextUtils.equals(AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY, mediaDirLocation))
-                        directory.setTitle(getString(R.string.internal_memory));
+                        directory.setDisplayTitle(getString(R.string.internal_memory));
                     mAdapter.addItem(directory, false, false);
                 }
                 if (mReadyToDisplay) {
