@@ -39,6 +39,7 @@ import android.view.ViewGroup;
 import android.widget.ImageView;
 
 import org.videolan.vlc.R;
+import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.helpers.AsyncImageLoader;
 import org.videolan.vlc.gui.helpers.AudioUtil;
 import org.videolan.vlc.gui.helpers.BitmapUtil;
@@ -56,7 +57,6 @@ public class CardPresenter extends Presenter {
     private Resources mRes;
     private static int CARD_WIDTH;
     private static int CARD_HEIGHT = 0;
-    private static MediaDatabase sMediaDatabase = MediaDatabase.getInstance();
     private static Drawable sDefaultCardImage;
     private static Handler sHandler = new Handler(Looper.getMainLooper());
 
@@ -76,16 +76,12 @@ public class CardPresenter extends Presenter {
             mCardView = (ImageCardView) view;
         }
 
-        public ImageCardView getCardView() {
-            return mCardView;
-        }
-
         protected void updateCardViewImage(MediaWrapper mediaWrapper) {
             mCardView.getMainImageView().setScaleType(ImageView.ScaleType.FIT_CENTER);
             if (!TextUtils.isEmpty(mediaWrapper.getArtworkURL()) && mediaWrapper.getArtworkURL().startsWith("http")) {
                 AsyncImageLoader.LoadImage(new HttpImageLoader(mediaWrapper.getArtworkURL()), mCardView);
             } else {
-                AsyncImageLoader.LoadImage(new CoverFetcher(mContext, mediaWrapper), mCardView);
+                AsyncImageLoader.LoadImage(new CoverFetcher(mediaWrapper), mCardView);
             }
         }
 
@@ -107,7 +103,7 @@ public class CardPresenter extends Presenter {
     }
 
     @Override
-    public void onBindViewHolder(Presenter.ViewHolder viewHolder, Object item) {
+    public void onBindViewHolder(Presenter.ViewHolder viewHolder, final Object item) {
         ViewHolder holder = ((ViewHolder) viewHolder);
         if (item instanceof MediaWrapper) {
             MediaWrapper mediaWrapper = (MediaWrapper) item;
@@ -118,6 +114,13 @@ public class CardPresenter extends Presenter {
                         R.drawable.ic_video_collection_big));
             else
                 holder.updateCardViewImage(mediaWrapper);
+            holder.view.setOnLongClickListener(new View.OnLongClickListener() {
+                @Override
+                public boolean onLongClick(View v) {
+                    TvUtil.showMediaDetail(v.getContext(), (MediaWrapper) item);
+                    return true;
+                }
+            });
         } else if (item instanceof MusicFragment.ListItem) {
             MusicFragment.ListItem listItem = (MusicFragment.ListItem) item;
             MediaWrapper MediaWrapper = listItem.mediaList.get(0);
@@ -215,20 +218,18 @@ public class CardPresenter extends Presenter {
 
     public static class CoverFetcher implements AsyncImageLoader.Callbacks{
         MediaWrapper mediaWrapper;
-        private static Activity context;
         private static Resources res;
 
-        CoverFetcher(Activity context, MediaWrapper mediaWrapper){
+        CoverFetcher(MediaWrapper mediaWrapper){
             this.mediaWrapper = mediaWrapper;
-            this.context = context;
-            res = context.getResources();
+            res = VLCApplication.getAppResources();
         }
 
         @Override
         public Bitmap getImage() {
-            Bitmap picture = null;
+            Bitmap picture;
             if (mediaWrapper.getType() == mediaWrapper.TYPE_AUDIO) {
-                picture = AudioUtil.getCover(context, mediaWrapper, 320);
+                picture = AudioUtil.getCover(VLCApplication.getAppContext(), mediaWrapper, 320);
                 if (picture == null)
                     picture = BitmapFactory.decodeResource(res, R.drawable.ic_browser_audio_big_normal);
             } else if (mediaWrapper.getType() == mediaWrapper.TYPE_VIDEO) {
