@@ -66,7 +66,7 @@ import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.media.Thumbnailer;
 import org.videolan.vlc.util.FileUtils;
 import org.videolan.vlc.util.VLCInstance;
-import org.videolan.vlc.view.AutoFitRecyclerView;
+import org.videolan.vlc.gui.view.AutoFitRecyclerView;
 
 import java.util.ArrayList;
 import java.util.List;
@@ -103,7 +103,7 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
         /* Load the thumbnailer */
         FragmentActivity activity = getActivity();
         if (activity != null)
-            mThumbnailer = new Thumbnailer(activity, activity.getWindowManager().getDefaultDisplay());
+            mThumbnailer = new Thumbnailer();
     }
 
     @Override
@@ -183,7 +183,6 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
             updateList();
         else {
             mViewNomedia.setVisibility(View.GONE);
-            focusHelper(false);
         }
         //Get & set times
         ArrayMap<String, Long> times = MediaDatabase.getInstance().getVideoTimes();
@@ -308,25 +307,31 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
                 return true;
             case R.id.video_list_delete:
                 mVideoAdapter.remove(position);
-                UiTools.snackerWithCancel(getView(), getString(R.string.file_deleted), new Runnable() {
-                    @Override
-                    public void run() {
-                        deleteMedia(media);
-                    }
-                }, new Runnable() {
-                    @Override
-                    public void run() {
-                        mVideoAdapter.add(position, media);
-                    }
-                });
+                if (getView() != null)
+                    UiTools.snackerWithCancel(getView(), getString(R.string.file_deleted), new Runnable() {
+                        @Override
+                        public void run() {
+                            deleteMedia(media);
+                        }
+                    }, new Runnable() {
+                        @Override
+                        public void run() {
+                            mVideoAdapter.add(position, media);
+                        }
+                    });
                 return true;
             case R.id.video_group_play:
                 MediaUtils.openList(getActivity(), ((MediaGroup) media).getAll(), 0);
+                return true;
             case R.id.video_list_append:
                 if (media instanceof MediaGroup)
                     mService.append(((MediaGroup)media).getAll());
                 else
                     mService.append(media);
+                return true;
+            case R.id.video_download_subtitles:
+                MediaUtils.getSubs(getActivity(), media);
+                return true;
         }
         return false;
     }
@@ -359,12 +364,13 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
         boolean hasInfo = false;
         final Media media = new Media(VLCInstance.get(), mediaWrapper.getUri());
         media.parse();
+        boolean canWrite = FileUtils.canWrite(mediaWrapper.getLocation());
         if (media.getMeta(Media.Meta.Title) != null)
             hasInfo = true;
         media.release();
         menu.findItem(R.id.video_list_info).setVisible(hasInfo);
-        menu.findItem(R.id.video_list_delete).setVisible(
-                FileUtils.canWrite(mediaWrapper.getLocation()));
+        menu.findItem(R.id.video_list_delete).setVisible(canWrite);
+        menu.findItem(R.id.video_download_subtitles).setVisible(canWrite);
         if (!AndroidUtil.isHoneycombOrLater()) {
             menu.findItem(R.id.video_list_play_all).setVisible(false);
             menu.findItem(R.id.video_list_append).setVisible(false);
@@ -374,9 +380,7 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
     @Override
     public boolean onContextItemSelected(MenuItem menu) {
         ContextMenuRecyclerView.RecyclerContextMenuInfo info = (ContextMenuRecyclerView.RecyclerContextMenuInfo) menu.getMenuInfo();
-        if (info != null && handleContextItemSelected(menu, info.position))
-            return true;
-        return super.onContextItemSelected(menu);
+        return info != null && handleContextItemSelected(menu, info.position);
     }
 
     /**
@@ -388,16 +392,6 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
         mVideoAdapter.update(item);
     }
 
-    private void focusHelper(boolean idIsEmpty) {
-        View parent = getView();
-        if (getActivity() == null || !(getActivity() instanceof MainActivity))
-            return;
-        MainActivity activity = (MainActivity)getActivity();
-        activity.setMenuFocusDown(idIsEmpty, android.R.id.list);
-        activity.setSearchAsFocusDown(idIsEmpty, parent,
-                android.R.id.list);
-    }
-
     public void updateList() {
         if (!mSwipeRefreshLayout.isRefreshing())
             mSwipeRefreshLayout.setRefreshing(true);
@@ -412,7 +406,7 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
             VLCApplication.runBackground(new Runnable() {
                 @Override
                 public void run() {
-                    final ArrayList<MediaWrapper> displayList = new ArrayList<MediaWrapper>();
+                    final ArrayList<MediaWrapper> displayList = new ArrayList<>();
 
                     if (mGroup != null || itemList.size() <= 10) {
                         for (MediaWrapper item : itemList) {
@@ -438,8 +432,7 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
                         display();
                 }
             });
-        } else
-            focusHelper(true);
+        }
         stopRefresh();
     }
 
@@ -520,7 +513,6 @@ public class VideoGridFragment extends MediaBrowserFragment implements ISortable
                     mViewNomedia.setVisibility(mVideoAdapter.getItemCount() > 0 ? View.GONE : View.VISIBLE);
                     mReadyToDisplay = true;
                     mGridView.requestFocus();
-                    focusHelper(false);
                 }
             });
     }
