@@ -34,6 +34,7 @@ import android.text.TextUtils;
 
 import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.vlc.VLCApplication;
+import org.videolan.vlc.media.MediaWrapper;
 
 import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
@@ -44,9 +45,18 @@ import java.io.FileOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.OutputStream;
+import java.nio.ByteBuffer;
+import java.nio.ByteOrder;
+import java.nio.LongBuffer;
+import java.nio.channels.FileChannel;
 
 public class FileUtils {
 
+    /**
+     * Size of the chunks that will be hashed in bytes (64 KB)
+     */
+    private static final int HASH_CHUNK_SIZE = 64 * 1024;
+
     public interface Callback {
         void onResult(boolean success);
     }
@@ -75,6 +85,17 @@ public class FileUtils {
         return parentPath;
     }
 
+    /*
+     * Convert file:// uri from real path to emulated FS path.
+     */
+    public static Uri convertLocalUri(Uri uri) {
+        if (!TextUtils.equals(uri.getScheme(), "file") || !uri.getPath().startsWith("/sdcard"))
+            return uri;
+        String path = uri.getPath();
+        path = path.replace("/sdcard", AndroidDevices.EXTERNAL_PUBLIC_DIRECTORY);
+        return Uri.parse("file://"+path);
+    }
+
     public static String getPathFromURI(Uri contentUri) {
         Cursor cursor = null;
         try {
@@ -215,6 +236,30 @@ public class FileUtils {
         });
     }
 
+    public static boolean canSave(MediaWrapper mw){
+        if (mw == null || mw.getUri() == null)
+            return false;
+        String scheme = mw.getUri().getScheme();
+        if (TextUtils.equals(scheme, "file"))
+            return false;
+        return TextUtils.equals(scheme, "smb")   ||
+                TextUtils.equals(scheme, "nfs")  ||
+                TextUtils.equals(scheme, "ftp")  ||
+                TextUtils.equals(scheme, "ftps") ||
+                TextUtils.equals(scheme, "sftp");
+    }
+
+    public static boolean canWrite(Uri uri){
+        if (uri == null)
+            return false;
+        if (TextUtils.equals("file", uri.getScheme()))
+            return canWrite(uri.toString());
+        if (TextUtils.equals("content", uri.getScheme()))
+            return canWrite(getPathFromURI(uri));
+        return false;
+
+    }
+
     public static boolean canWrite(String path){
         if (path == null)
             return false;
@@ -229,4 +274,48 @@ public class FileUtils {
         File file = new File(path);
         return (file.exists() && file.canWrite());
     }
+
+    public static String computeHash(File file) {
+        long size = file.length();
+        long chunkSizeForFile = Math.min(HASH_CHUNK_SIZE, size);
+        long head = 0;
+        long tail = 0;
+        FileInputStream fis = null;
+        FileChannel fileChannel = null;
+        try {
+            fis = new FileInputStream(file);
+            fileChannel = fis.getChannel();
+            head = computeHashForChunk(fileChannel.map(FileChannel.MapMode.READ_ONLY, 0, chunkSizeForFile));
+
+            //Alternate way to calculate tail hash for files over 4GB.
+            ByteBuffer bb = ByteBuffer.allocateDirect((int)chunkSizeForFile);
+            int read;
+            long position = Math.max(size - HASH_CHUNK_SIZE, 0);
+            while ((read = fileChannel.read(bb, position)) > 0) {
+                position += read;
+            }
+            bb.flip();
+            tail = computeHashForChunk(bb);
+
+            return String.format("%016x", size + head + tail);
+        } catch (FileNotFoundException e1) {
+            e1.printStackTrace();
+            return null;
+        }
+        catch (IOException e) {
+            e.printStackTrace();
+            return null;
+        }finally {
+            Util.close(fileChannel);
+            Util.close(fis);
+        }
+    }
+
+    private static long computeHashForChunk(ByteBuffer buffer) {
+        LongBuffer longBuffer = buffer.order(ByteOrder.LITTLE_ENDIAN).asLongBuffer();
+        long hash = 0;
+        while (longBuffer.hasRemaining())
+            hash += longBuffer.get();
+        return hash;
+    }
 }
